# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API Clients.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, constr, validator

class ProviderDto(BaseModel):
    """
    A valid provider record must include either an `organization_name` or both a `first_name` and `last_name`.  The `npi` must always be exactly 10 numeric digits.   # noqa: E501
    """
    first_name: Optional[constr(strict=True, max_length=35, min_length=1)] = Field(default=None, description="The provider's first name. Required if `organization_name` is not provided.  Must contain 1-35 alphanumeric characters.  ")
    last_name: Optional[constr(strict=True, max_length=60, min_length=1)] = Field(default=None, description="The provider's last name. Required if `organization_name` is not provided.  Must contain 1-60 alphanumeric characters. ")
    npi: constr(strict=True) = Field(default=..., description="The National Provider Identifier (NPI), assigned by the Centers for Medicare & Medicaid Services.  This identifier is always a 10-digit numeric value.  Use the [NPI Registry](https://npiregistry.cms.hhs.gov/search) to verify or look up NPI details. ")
    organization_name: Optional[constr(strict=True, max_length=60, min_length=0)] = Field(default=None, description="The name of the provider's organization. Required if both `first_name` and `last_name` are not provided.  Must contain up to 60 characters. ")
    __properties = ["first_name", "last_name", "npi", "organization_name"]

    @validator('npi')
    def npi_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^\d{10}$", value):
            raise ValueError(r"must validate the regular expression /^\d{10}$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def _json_serializer(self, obj):
        """JSON serializer function for datetime objects"""
        if isinstance(obj, datetime):
            return obj.isoformat()

        raise TypeError(f"Type {type(obj)} not serializable")

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict(), default=self._json_serializer)

    @classmethod
    def from_json(cls, json_str: str) -> ProviderDto:
        """Create an instance of ProviderDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProviderDto:
        """Create an instance of ProviderDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ProviderDto.parse_obj(obj)

        _obj = ProviderDto.parse_obj({
            "first_name": obj.get("first_name"),
            "last_name": obj.get("last_name"),
            "npi": obj.get("npi"),
            "organization_name": obj.get("organization_name")
        })
        return _obj


